"track.exons"This class is a variation of the '>track.table class dedicated to exons, enforcing new drawing parameter defaults and a few specialized methods.
Objects can be created by two distincts means :
Using the corresponding constructors, which work like the track.table constructor.
Importing a '>track.table object in an empty object created by a call to new (see Examples).
Class '>track.table, directly.
Class '>refTable, by class '>track.table, distance 2.
Class '>crossable, by class '>track.table, distance 2.
Class '>sliceable, by class '>track.table, distance 3.
Class '>drawable, by class '>track.table, distance 4.
All reference classes extend and inherit methods from '>envRefClass.
The following fields are inherited (from the corresponding class):
The following methods are inherited (from the corresponding class):